﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Collections.Specialized;

namespace WpfApplication1
{
	public class Family : INotifyPropertyChanged, IPath
	{
		private string name;

		public Family(string name)
		{
			this.Name = name;
			this.Members = new ObservableCollection<Member>();
			this.Members.CollectionChanged += Members_CollectionChanged;
		}

		private void Members_CollectionChanged(object sender, NotifyCollectionChangedEventArgs e)
		{
			if (e.Action == NotifyCollectionChangedAction.Add)
			{
				var item = e.NewItems[0] as IPath;
				item.Parent = this;
			}
		}

		public string Name
		{
			get
			{
				return this.name;
			}
			set
			{
				if (this.name != value)
				{
					this.name = value;
					OnNotifyPropertyChanged("Name");
				}
			}
		}

		public ObservableCollection<Member> Members
		{
			get;
			set;
		}

		#region INotifyPropertyChanged Members

		public event PropertyChangedEventHandler PropertyChanged;
		private void OnNotifyPropertyChanged(string propertyName)
		{
			if (PropertyChanged != null)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}

		#endregion

		public string GetFullPath()
		{
			if (this.Parent != null)
			{
				return this.Parent.GetFullPath() + "|" + this.ToString();
			}
			return this.ToString();
		}

		public IPath Parent
		{
			get;
			set;
		}

		public override string ToString()
		{
			return this.Name;
		}
	}
}
